@@ -1,18 +1,19 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::MungeFile::WithData;
-BEGIN {
-  $Dist::Zilla::Plugin::MungeFile::WithData::AUTHORITY = 'cpan:ETHER';
-}
 # ABSTRACT: (DEPRECATED) Modify files in the build, with templates and DATA section
-# vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::MungeFile::WithData::VERSION = '0.007';
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
+
+our $VERSION = '0.008';
+
 use Moose;
 extends 'Dist::Zilla::Plugin::MungeFile::WithDataSection';
 use namespace::autoclean;
 
 before register_component => sub {
-    warn "!!! [MungeFile::WithData] is deprecated and will be removed in a future release; replace it with [MungeFile::WithDataSection]\n";
+    warnings::warnif('deprecated',
+        "!!! [MungeFile::WithData] is deprecated and will be removed in a future release; replace it with [MungeFile::WithDataSection]\n",
+    );
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -23,15 +24,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge
-
 =head1 NAME
 
 Dist::Zilla::Plugin::MungeFile::WithData - (DEPRECATED) Modify files in the build, with templates and DATA section
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -51,7 +50,7 @@ See its documentation for a full list of options available.
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
